<?php
namespace Folha\Logic\ESocial\Eventos\Data;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-2305 - Trabalhador Sem Vínculo - Alteração Contratual
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S2305
{

    /**
     * Retorna os dados que serao utilizados para a geracao do(s) arquivo(s) do evento S-2305, Trabalhador Sem Vínculo - Alteração Contratual
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo,
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo)
    {
        $S2305 = \Folha\Repositories\GpeEsocialRegistro::dataSetEsocial_S2305(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo,
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $versaoEsocial, $tpAmbiente, $indRetificacao, $nrRecibo
        );

        foreach ($S2305 as &$row) {
            /*Informações complementares*/
            $row['INFOCOMPLEMENTARES'] = '1';

            /*Cargo e Função*/
            if (isset($row['CODCARGO']) or isset($row['CODFUNCAO'])) {
                $row['CARGOFUNCAO'] = '1';
            }

            /*Remuneração - diretor não empregado, servidor público indicado a conselho e membro de Conselho Tutelar*/
            if (in_array($row['CODCATEG'], array('721','722','305','771'))) {
                $row['REMUNERACAO'] = '1';
            }

            /*FGTS - Diretor não empregado com direito ao FGTS [721] e para o Contribuinte Individual Membro de Conselho Tutelar [771]*/
            if (in_array($row['CODCATEG'], array('721','771'))) {
                $row['FGTS'] = '1';
            }

            /*Dirigente Sindical*/
            if (isset($row['CATEGORIG'])) {
                $row['INFODIRIGENTESINDICAL'] = '1';
            }

            /*Trabalhador Cedido*/
            if (isset($row['INFOTRABCEDIDO_CATEGORIG'])) {
                $row['INFOTRABCEDIDO'] = '1';
            }

            /*Estagiário*/
            if (isset($row['NATESTAGIO'])) {
                $row['INFOESTAGIARIO'] = '1';
            }
        }

        return $S2305;
    }

}