<?php
namespace Folha\Repositories;

class GpePessoa extends \Doctrine\ORM\EntityRepository
{
    public static function getTipo2Rais($ano, $nrorg, $estrutura, $vinculos = null)
    {

        $data_inicial = "01/01/$ano";
        $data_final = "31/12/$ano";
        $proxAno = $ano+1;
        $where = "NRESTRUTURAM IN ( $estrutura)";
        
        if($vinculos){
            $where .= " AND (NRVINCULOM = $vinculos)";
        }
        
        $sql = <<<SQL
SELECT 
    SEQUENCIAL,                
    CNPJ,                      
    '00'                      AS PREFIXO,
    2                         AS TIPO_REGISTRO,
    PIS_PASEP,                 
    NOME,                      
    DATA_NASCIMENTO,           
    NACIONALIDADE,             
    ANO_CHEGADA,               
    GRAU_INSTRUCAO,            
    CPF,                       
    CTPS,                      
    SERIE_CTPS,                
    DATA_ADMISSAO,             
    TIPO_ADMISSAO,             
    SALARIO_CONTRATUAL,        
    TIPO_PAGAMENTO,            
    HORAS_SEMANAIS,            
    CBO,                       
    VINCULO,                   
    TIPO_RECISÃO,
    DATA_RECISAO,              
    RACA,                  
    DEFICIENCIA,           
    TIPO_DEFICIENCIA,      
    2                         AS INDICADOR_ALVARA,
    SEXO,                  
    NULL                      AS VALOR_BANCO_HORAS,
    NULL                      AS QUAT_MESES_BANCO_HORAS,
    MUNICIPIO_TRABALHO,        
    1                         AS FILIADO_SINDICATO,
    NULL                      AS INF_EXCLUSIVO_EMPRESA,
    NRORG,
    NRESTRUTURAM,
    NRVINCULOM,
    NRPESSOA,
    DTRESCISAOVINC,
    DTAVISOPREVIO
    
FROM (
    SELECT
        ROWNUM                                                                                          AS SEQUENCIAL,                  
        ESTRUTURAH.CDCNPJESTRUT                                                                         AS CNPJ,                        
        GPE_PESSOAH.NRPISPASEPPES                                                                       AS PIS_PASEP,                   
        GPE_PESSOAH.NMPESSOA                                                                            AS NOME,                        
        GPE_PESSOAH.DTNASCPESSOA                                                                        AS DATA_NASCIMENTO,             
        GPE_NACIONALIDADE.CDRAIS                                                                        AS NACIONALIDADE,               
        GPE_PESSOAH.NRANOCHEGAPAIS                                                                      AS ANO_CHEGADA,                 
        GPE_GRAUINSTR.CODRAIS                                                                           AS GRAU_INSTRUCAO,              
        GPE_PESSOAH.NRCPFPESSOA                                                                         AS CPF,                         
        GPE_PESSOAH.NRCTPSPESSOA                                                                        AS CTPS,                        
        GPE_PESSOAH.NRSERIECTPSPES                                                                      AS SERIE_CTPS,                  
        GPE_VINCULOM.DTADMISSAOVINC                                                                     AS DATA_ADMISSAO,               
        FPA_TPADMISSAO.CODRAIS                                                                          AS TIPO_ADMISSAO,               
        GPE_ALTESALARIO.VRSALARIO*100                                                                   AS SALARIO_CONTRATUAL,          
        (CASE GPE_VINCULOH.IDTPPAGAMENTO
            WHEN 'MENSAL'
                THEN 1
            WHEN 'QUINZENAL'
                THEN 2
            WHEN 'SEMANAL'
                THEN 3
            WHEN 'DIARIO'
                THEN 4
            WHEN 'MENSAL_SALARIO_HORA'
                THEN 5
            ELSE 7
        END)                                                                                            AS TIPO_PAGAMENTO,
        GPE_ESCALATRABH.QTHRSEMESCTRABH                                                                 AS HORAS_SEMANAIS,
        GPE_CBO.CDRAIS                                                                                  AS CBO,
        GPE_VINCULOEMPREG.CODRAIS                                                                       AS VINCULO,                     
        FPA_TPDEMISSAO.CODRAIS                                                                          AS TIPO_RECISÃO,
        DECODE(TO_CHAR(GPE_VINCULOM.DTRESCISAOVINC, 'YYYY'), $ano, GPE_VINCULOM.DTRESCISAOVINC, NULL)   AS DATA_RECISAO,
        (CASE GPE_PESSOAH.NRRACAPESSOA
            WHEN 1
                THEN 1
            WHEN 2
                THEN 2
            WHEN 3
                THEN 4
            WHEN 4
                THEN 6
            WHEN 5
                THEN 8
            ELSE 9
        END)                                                                                            AS RACA,                        
        (CASE
            WHEN GPE_PESSOAH.NRCONDFISPES = 1
                THEN 2
            ELSE 1
        END)                                                                                            AS DEFICIENCIA,                 
        (CASE NRCONDFISPES
            WHEN 1
                THEN 0
            WHEN 2
                THEN 1
            WHEN 3
                THEN 2
            WHEN 4
                THEN 3
            WHEN 5
                THEN 4
            WHEN 6
                THEN 5
            WHEN 7
                THEN 6
        END)                                                                                            AS TIPO_DEFICIENCIA,
        2                                                                                               AS INDICADOR_ALVARA,
        (CASE GPE_PESSOAH.IDSEXOPESSOA
            WHEN 'M'
                THEN 1
            WHEN 'F'
                THEN 2
        END)                                                                                            AS SEXO,
        MUNICIPIO.CDMUNICIBGE                                                                           AS MUNICIPIO_TRABALHO,
        GPE_PESSOA.NRORG,
        ESTRUTURAH.NRESTRUTURAM,
        GPE_VINCULOM.NRVINCULOM,
        GPE_PESSOA.NRPESSOA,
        GPE_VINCULOM.DTRESCISAOVINC,
        GPE_VINCULOM.DTAVISOPREVIO

    FROM GPE_PESSOA

    INNER JOIN GPE_PESSOAH
        ON GPE_PESSOAH.NRPESSOA = GPE_PESSOA.NRPESSOA
        AND GPE_PESSOAH.NRORG = GPE_PESSOA.NRORG
        AND GPE_PESSOAH.DTMESCOMPETENC = (SELECT MAX(MAX_PESSOAH.DTMESCOMPETENC) DTMESCOMPETENC
                                            FROM GPE_PESSOAH MAX_PESSOAH
                                            WHERE MAX_PESSOAH.NRORG = GPE_PESSOAH.NRORG
                                            AND MAX_PESSOAH.DTMESCOMPETENC <= '$data_final'
                                            AND MAX_PESSOAH.NRPESSOA = GPE_PESSOAH.NRPESSOA)
                                    
    INNER JOIN GPE_VINCULOM
        ON GPE_VINCULOM.NRPESSOA = GPE_PESSOA.NRPESSOA
        AND GPE_VINCULOM.NRORG = GPE_PESSOA.NRORG

    INNER JOIN GPE_VINCULOH
        ON GPE_VINCULOM.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
        AND GPE_VINCULOM.NRORG = GPE_VINCULOH.NRORG
        AND GPE_VINCULOH.DTMESCOMPETENC = ( SELECT MAX(MAX_VINCULOH.DTMESCOMPETENC) DTMESCOMPETENC
                                            FROM GPE_VINCULOH MAX_VINCULOH
                                            WHERE MAX_VINCULOH.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
                                                AND MAX_VINCULOH.NRORG = GPE_VINCULOH.NRORG
                                                AND MAX_VINCULOH.DTMESCOMPETENC <= '$data_final')

    INNER JOIN GPE_NACIONALIDADE
        ON GPE_PESSOAH.NRNACIONALID = GPE_NACIONALIDADE.NRNACIONALIDADE

    INNER JOIN GPE_GRAUINSTR
        ON GPE_GRAUINSTR.NRGRAUINSTR = GPE_PESSOAH.NRGRAUINSTR

    INNER JOIN GPE_VINCULOEMPREG
        ON GPE_VINCULOEMPREG.NRVINCULOEMPREG = GPE_VINCULOM.NRVINCULOEMPREG
        
    LEFT JOIN FPA_TPADMISSAO
        ON FPA_TPADMISSAO.NRTPADMISSAO = GPE_VINCULOM.NRTPADMISSAO

    LEFT JOIN FPA_TPDEMISSAO
        ON FPA_TPDEMISSAO.NRTPDEMISSAO = GPE_VINCULOM.NRTPDEMISSAO

    INNER JOIN GPE_ALTESALARIO
        ON GPE_ALTESALARIO.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
        AND GPE_ALTESALARIO.NRORG = GPE_VINCULOM.NRORG
        AND GPE_ALTESALARIO.DTALTESALARIO = (SELECT MAX(MAX_ALTESALARIO.DTALTESALARIO)DTALTESALARIO
                                            FROM GPE_ALTESALARIO MAX_ALTESALARIO
                                            WHERE MAX_ALTESALARIO.DTALTESALARIO <= '$data_final'
                                                AND MAX_ALTESALARIO.NRORG = GPE_ALTESALARIO.NRORG
                                                AND MAX_ALTESALARIO.NRVINCULOM = GPE_ALTESALARIO.NRVINCULOM) 

    INNER JOIN ESTRUTURAH
        ON ESTRUTURAH.NRESTRUTURAM = GPE_VINCULOH.NRESTRUTLEGAL
        AND ESTRUTURAH.NRORG = GPE_VINCULOM.NRORG
        AND ESTRUTURAH.DTMESCOMPETENC = ( SELECT MAX(MAX_ESTRUTURAH.DTMESCOMPETENC) DTMESCOMPETENC
                                            FROM ESTRUTURAH MAX_ESTRUTURAH
                                            WHERE MAX_ESTRUTURAH.NRESTRUTURAM = ESTRUTURAH.NRESTRUTURAM
                                                AND MAX_ESTRUTURAH.NRORG = ESTRUTURAH.NRORG
                                                AND MAX_ESTRUTURAH.DTMESCOMPETENC <= '$data_final')

    INNER JOIN GPE_ESCALATRABH
        ON GPE_ESCALATRABH.NRORG = GPE_VINCULOH.NRORG
        AND GPE_ESCALATRABH.NRESCALATRABM = GPE_VINCULOH.NRESCALATRABM
        AND GPE_ESCALATRABH.DTMESCOMPETENC =   (SELECT MAX(MAX_ESCALATRABH.DTMESCOMPETENC) DTMESCOMPETENC
                                                FROM GPE_ESCALATRABH MAX_ESCALATRABH
                                                WHERE MAX_ESCALATRABH.NRORG = GPE_ESCALATRABH.NRORG
                                                    AND MAX_ESCALATRABH.NRESCALATRABM = GPE_ESCALATRABH.NRESCALATRABM
                                                    AND MAX_ESCALATRABH.DTMESCOMPETENC <= '$data_final')

    INNER JOIN GPE_OCUPACAOH
        ON GPE_OCUPACAOH.NRORG = GPE_VINCULOH.NRORG
        AND GPE_OCUPACAOH.NROCUPACAOM    = GPE_VINCULOH.NRCARGO
        AND GPE_OCUPACAOH.DTMESCOMPETENC = (SELECT MAX(MAX_OCUPACAOH.DTMESCOMPETENC) DTMESCOMPETENC
                                            FROM GPE_OCUPACAOH MAX_OCUPACAOH
                                            WHERE MAX_OCUPACAOH.NRORG = GPE_OCUPACAOH.NRORG
                                                AND MAX_OCUPACAOH.NROCUPACAOM = GPE_OCUPACAOH.NROCUPACAOM
                                                AND MAX_OCUPACAOH.DTMESCOMPETENC <= '$data_final')

    LEFT JOIN GPE_CBO
        ON GPE_CBO.NRCBO = GPE_OCUPACAOH.NRCBO

    INNER JOIN ENDERECOPARC
        ON ESTRUTURAH.NRPARCNEGOCIO = ENDERECOPARC.NRPARCNEGOCIO
        AND ESTRUTURAH.NRORG = ENDERECOPARC.NRORG

    INNER JOIN MUNICIPIO
        ON MUNICIPIO.CDMUNICIPIO = ENDERECOPARC.CDMUNICIPIO
        AND MUNICIPIO.CDPAIS = ENDERECOPARC.CDPAIS 
        AND MUNICIPIO.SGESTADO = ENDERECOPARC.SGESTADO

    WHERE GPE_VINCULOM.DTADMISSAOVINC < '$data_final'
        AND (GPE_VINCULOM.DTRESCISAOVINC IS NULL OR GPE_VINCULOM.DTRESCISAOVINC > '$data_inicial')
        AND GPE_VINCULOM.NRORG = $nrorg
        AND GPE_VINCULOM.NRTIPOVINCULOM IN (1, 7, 9)) GPE_PESSOA
 WHERE $where

SQL;
            $result = \Setforms2\Runtime\Framework::getInstance()->fetchAll($sql);
            return ($result) ? $result : false;
        }

        public static function getRespRetificacao($nrorg, $nrpessoa)
        {
            $sql = <<<SQL
    SELECT GPE_PESSOAH.NMPESSOA      AS NOME,
        GPE_PESSOAH.NRCPFPESSOA      AS CPF,
        GPE_PESSOAH.DTNASCPESSOA     AS DATA_NASCIMENTO,
        COMUNICAPARC.CDCOMUNICAPARC  AS EMAIL,
        COMUNICAPARC.NRORG           AS NRORG,
        '0'                          AS CREA

    FROM GPE_PESSOA
    INNER JOIN GPE_PESSOAH
        ON GPE_PESSOAH.NRPESSOA = GPE_PESSOA.NRPESSOA
        AND GPE_PESSOAH.NRORG = GPE_PESSOA.NRORG
    INNER JOIN (SELECT MAX(GPE_PESSOAH.DTMESCOMPETENC) DTMESCOMPETENC,
                       GPE_PESSOAH.NRPESSOA,
                       GPE_PESSOAH.NRORG
                FROM GPE_PESSOAH
                GROUP BY GPE_PESSOAH.NRPESSOA,
                       GPE_PESSOAH.NRORG
        )MAX_PESSOAH
        ON MAX_PESSOAH.DTMESCOMPETENC = GPE_PESSOAH.DTMESCOMPETENC
        AND MAX_PESSOAH.NRORG = GPE_PESSOAH.NRORG
        AND MAX_PESSOAH.NRPESSOA = GPE_PESSOAH.NRPESSOA
    LEFT JOIN COMUNICAPARC
        ON GPE_PESSOA.NRORG = COMUNICAPARC.NRORG
        AND GPE_PESSOA.NRPARCNEGOCIO = COMUNICAPARC.NRPARCNEGOCIO
        AND COMUNICAPARC.CDFORMACOMU = '05'
    WHERE GPE_PESSOA.NRORG = $nrorg
    	AND GPE_PESSOA.NRPESSOA = $nrpessoa

SQL;

        $result = \Setforms2\Runtime\Framework::getInstance()->fetchAll($sql);
        return ($result) ? $result : false;

    }

    public static function getPreInformacao($ano, $nrorg, $estruturas)
    {
        if(is_array($estruturas))
            $estruturas = implode(', ',$estruturas);

        $sql = <<<SQl
SELECT *
FROM(
    SELECT  GPE_PESSOAH.NMPESSOA,
        GPE_PESSOAH.CDESTACIVIL,
        GPE_PESSOAH.NRANOCHEGAPAIS,
        GPE_PESSOAH.NRCPFPESSOA,
        GPE_PESSOAH.NRPISPASEPPES,
        GPE_PESSOAH.NRGRAUINSTR,
        GPE_PESSOAH.NRNACIONALID,
        GPE_PESSOAH.NRRGPESSOA,
        GPE_PESSOAH.DTNASCPESSOA,
        GPE_PESSOAH.IDSEXOPESSOA,
        GPE_VINCULOM.DTADMISSAOVINC,
        GPE_VINCULOM.DTRESCISAOVINC,
        GPE_VINCULOM.CDMATRICULA,
        GPE_VINCULOM.NRTIPOVINCULOM,
        GPE_VINCULOM.NRVINCULOEMPREG,
        GPE_VINCULOH.IDTPPAGAMENTO,
        GPE_VINCULOH.NRESTRUTLEGAL,
        GPE_VINCULOH.NRORG


    FROM GPE_PESSOA
    INNER JOIN GPE_PESSOAH
        ON GPE_PESSOAH.NRORG = GPE_PESSOA.NRORG
        AND GPE_PESSOAH.NRPESSOA = GPE_PESSOA.NRPESSOA

    INNER JOIN (
            SELECT MAX(GPE_PESSOAH.DTMESCOMPETENC) DTMESCOMPETENC,
                GPE_PESSOAH.NRPESSOA,
                GPE_PESSOAH.NRORG
            FROM GPE_PESSOAH
            GROUP BY GPE_PESSOAH.NRPESSOA,
                GPE_PESSOAH.NRORG
        )MAX_PESSOAH
        ON GPE_PESSOAH.DTMESCOMPETENC = MAX_PESSOAH.DTMESCOMPETENC
        AND GPE_PESSOAH.NRORG = MAX_PESSOAH.NRORG
        AND GPE_PESSOAH.NRPESSOA = MAX_PESSOAH.NRPESSOA

    INNER JOIN GPE_VINCULOM
        ON GPE_VINCULOM.NRPESSOA = GPE_PESSOA.NRPESSOA
        AND GPE_VINCULOM.NRORG = GPE_PESSOA.NRORG
        AND GPE_VINCULOM.DTADMISSAOVINC < '31/12/$ano'
        AND (GPE_VINCULOM.DTRESCISAOVINC > '01/01/$ano' OR GPE_VINCULOM.DTRESCISAOVINC IS NULL)

    INNER JOIN GPE_VINCULOH
        ON GPE_VINCULOM.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
        AND GPE_VINCULOM.NRORG = GPE_VINCULOH.NRORG

    INNER JOIN (
            SELECT MAX(GPE_VINCULOH.DTMESCOMPETENC) DTMESCOMPETENC,
                GPE_VINCULOH.NRVINCULOM,
                GPE_VINCULOH.NRORG
            FROM GPE_VINCULOH
            GROUP BY GPE_VINCULOH.NRVINCULOM,
                GPE_VINCULOH.NRORG
        )MAX_VINCULOH
        ON GPE_VINCULOH.DTMESCOMPETENC = MAX_VINCULOH.DTMESCOMPETENC
        AND GPE_PESSOAH.NRORG = MAX_PESSOAH.NRORG
        AND GPE_VINCULOH.NRVINCULOM = MAX_VINCULOH.NRVINCULOM
)VERIFICA_02
WHERE NRORG = $nrorg
    AND NRTIPOVINCULOM IN (1, 7, 9)
    AND NRESTRUTLEGAL IN ($estruturas)
SQl;

        $result = \Setforms2\Runtime\Framework::getInstance()->fetchAll($sql);
        return ($result)?$result:FALSE;

    }
    
}